@@ -1,9 +1,13 @@
 #ifndef _GSM_CGROUPS_H_
 #define _GSM_CGROUPS_H_
 
-#include "application.h"
+#include <string>
+#include <string_view>
+
+#include "procinfo.h"
 
-void get_process_cgroup_info (ProcInfo&info);
 bool cgroups_enabled ();
+std::string_view get_process_cgroup_name(std::string cgroup_file_text);
+void get_process_cgroup_info (ProcInfo&info);
 
 #endif /* _GSM_CGROUPS_H_ */
