@@ -42,7 +42,7 @@ typedef struct _GsmColorButtonClass GsmColorButtonClass;
 
 struct _GsmColorButton
 {
-  GtkDrawingArea parent_instance;
+  GtkWidget parent_instance;
 };
 
 /* Widget types */
@@ -52,12 +52,14 @@ enum
   GSMCP_TYPE_PIE,
   GSMCP_TYPE_NETWORK_IN,
   GSMCP_TYPE_NETWORK_OUT,
+  GSMCP_TYPE_DISK_READ,
+  GSMCP_TYPE_DISK_WRITE,
   GSMCP_TYPES
 };
 
 struct _GsmColorButtonClass
 {
-  GtkDrawingAreaClass parent_class;
+  GtkWidgetClass parent_class;
 };
 
 GType            gsm_color_button_get_type (void);
