@@ -9,6 +9,7 @@
 #include "smooth_refresh.h"
 #include "application.h"
 #include "settings-keys.h"
+#include "update_interval.h"
 #include "util.h"
 
 
@@ -79,7 +80,7 @@ SmoothRefresh::reset ()
   glibtop_get_cpu (&cpu);
   glibtop_get_proc_time (&proctime, getpid ());
 
-  this->interval = GsmApplication::get ()->config.update_interval;
+  this->interval = GsmApplication::get ().config.update_interval;
   this->last_pcpu = PCPU_LO;
   this->last_total_time = cpu.total;
   this->last_cpu_time = proctime.rtime;
@@ -98,7 +99,7 @@ SmoothRefresh::~SmoothRefresh()
 bool
 SmoothRefresh::get (guint &new_interval)
 {
-  const unsigned config_interval = GsmApplication::get ()->config.update_interval;
+  const unsigned config_interval = GsmApplication::get ().config.update_interval;
 
   g_assert (this->interval >= config_interval);
 
